@@ -1,4 +1,29 @@
 #!/usr/bin/perl
+
+=head1 AUTHOR
+
+Jonny Schulz <jschulz.cpan(at)bloonix.de>
+
+=head1 DESCRIPTION
+
+Benchmarks... what else could I say...
+
+=head1 POWERED BY
+
+     _    __ ____ ____ __  __ __ __   __
+    | |__|  |    |    |  \|  |__|\  \/  /
+    |  . |  |  | |  | |      |  | >    <
+    |____|__|____|____|__|\__|__|/__/\__\
+
+=head1 COPYRIGHT
+
+Copyright (C) 2007 by Jonny Schulz. All rights reserved.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
+
 use strict;
 use warnings;
 use Log::Handler;
